@@ -1,4 +1,3 @@
-
 #' @title Return job status
 #' @description Return status of the previously submitted job
 #' @param jobid Job ID of the previously submitted job
@@ -9,20 +8,26 @@
 #' @import utils
 #' @import jsonlite
 #'
-job_status <- function(jobid, token=NULL) {
+job_status <- function(jobid, token = NULL) {
   if (is.null(jobid)) {
     stop("jobid is null")
   }
 
   headers <- c()
-  if (!is.null(token)) { headers<-c(headers, "Authorization"=paste("Bearer",token)) }
+  if (!is.null(token)) {
+    headers <- c(headers, "Authorization" = paste("Bearer", token))
+  }
 
-  res <- GET(url=paste0("https://pcats.research.cchmc.org/api/job/",jobid,"/status"),
-             add_headers(headers))
+  res <- GET(
+    url = paste0("https://pcats.research.cchmc.org/api/job/", jobid, "/status"),
+    add_headers(headers)
+  )
 
-  if (res$status_code!=200) return(NULL)
+  if (res$status_code != 200) {
+    return(NULL)
+  }
 
-  status <- jsonlite::fromJSON(httr::content(res,as="text",encoding="utf-8"))
+  status <- jsonlite::fromJSON(httr::content(res, as = "text", encoding = "utf-8"))
 
   # status<-jsonlite::fromJSON(paste0("https://pcats.research.cchmc.org/api/job/",jobid,"/status"))
   status
